@@ -182,10 +182,10 @@ def test_simple_imputer_fit_transform_drop_all_nan_columns():
         pd.DataFrame(
             {
                 "all_nan": [np.nan, np.nan, np.nan],
-                "some_nan": [np.nan, 1, 0],
+                "some_nan": [pd.NA, 1, 0],
                 "another_col": [0, 1, 2],
             },
-        ),
+        ).astype({"some_nan": "Int64"}),
     )
 
 
@@ -207,10 +207,10 @@ def test_simple_imputer_transform_drop_all_nan_columns():
         pd.DataFrame(
             {
                 "all_nan": [np.nan, np.nan, np.nan],
-                "some_nan": [np.nan, 1, 0],
+                "some_nan": [pd.NA, 1, 0],
                 "another_col": [0, 1, 2],
             },
-        ),
+        ).astype({"some_nan": "Int64"}),
     )
 
 
@@ -484,10 +484,8 @@ def test_simple_imputer_woodwork_custom_overrides_returned_by_components(
         impute_strategy_to_use = "most_frequent"
 
     imputer = SimpleImputer(impute_strategy=impute_strategy_to_use)
-    imputer.fit(X, y)
-    transformed = imputer.transform(X, y)
+    transformed = imputer.fit_transform(X, y)
     assert isinstance(transformed, pd.DataFrame)
-
     assert {k: type(v) for k, v in transformed.ww.logical_types.items()} == {
         data: logical_type,
     }
@@ -523,14 +521,14 @@ def test_simple_imputer_ignores_natural_language(
     """Test to ensure that the simple imputer just passes through
     natural language columns, unchanged."""
     if df_composition == "single_column":
-        X_df = imputer_test_data[["natural language col"]]
-        X_df.ww.init()
+        X_df = imputer_test_data.ww[["natural language col"]]
     elif df_composition == "full_df":
-        X_df = imputer_test_data[["int col", "float col", "natural language col"]]
-        X_df.ww.init()
+        X_df = imputer_test_data.ww[["int col", "float col", "natural language col"]]
 
     if has_nan == "has_nan":
         X_df.iloc[-1, :] = None
+        if "int col" in X_df:
+            X_df = X_df.astype({"int col": "Int64"})
         X_df.ww.init()
     y = pd.Series([x for x in range(X_df.shape[1])])
 
@@ -551,10 +549,16 @@ def test_simple_imputer_ignores_natural_language(
         if numeric_impute_strategy == "mean" and has_nan == "has_nan":
             ans = X_df.mean()
             ans["natural language col"] = pd.NA
+            X_df = X_df.astype(
+                {"int col": float},
+            )
             X_df.iloc[-1, :] = ans
         elif numeric_impute_strategy == "median" and has_nan == "has_nan":
             ans = X_df.median()
             ans["natural language col"] = pd.NA
+            X_df = X_df.astype(
+                {"int col": float},
+            )  # Convert to float as the imputer will do this as we're requesting the mean
             X_df.iloc[-1, :] = ans
         elif numeric_impute_strategy == "constant" and has_nan == "has_nan":
             X_df.iloc[-1, 0:2] = fill_value
@@ -562,7 +566,7 @@ def test_simple_imputer_ignores_natural_language(
             ans = X_df.mode().iloc[0, :]
             ans["natural language col"] = pd.NA
             X_df.iloc[-1, :] = ans
-        assert_frame_equal(result, X_df)
+        assert_frame_equal(result, X_df, check_dtype=False)
     elif df_composition == "single_column":
         assert_frame_equal(result, X_df)
 
